@@ -35,7 +35,7 @@
 #include <bits/os_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20040419
+#define __GLIBCXX__ 20041105
 
 // Allow use of "export template." This is currently not a feature
 // that g++ supports.
@@ -122,8 +122,8 @@ namespace std
 // Define if code specialized for wchar_t should be used.
 #define _GLIBCXX_USE_WCHAR_T 1
 
-// Define if using setrlimit to limit memory usage during 'make check'.
-#define _GLIBCXX_MEM_LIMITS 1
+// Define if using setrlimit to set resource limits during 'make check'.
+#define _GLIBCXX_RES_LIMITS 1
 
 // Define to use concept checking code from the boost libraries.
 /* #undef _GLIBCXX_CONCEPT_CHECKS */
@@ -145,6 +145,9 @@ namespace std
 // Define if LFS support is available.
 #define _GLIBCXX_USE_LFS 1
 
+// Define if a fully dynamic basic_string is wanted.
+/* #undef _GLIBCXX_FULLY_DYNAMIC_STRING */
+
 // Define if NLS translations are to be used.
 #define _GLIBCXX_USE_NLS 1
 
@@ -458,6 +461,21 @@ namespace std
 /* Define to 1 if you have the `m' library (-lm). */
 #define _GLIBCXX_HAVE_LIBM 1
 
+/* Only used in build directory testsuite_hooks.h. */
+#define _GLIBCXX_HAVE_LIMIT_AS 1
+
+/* Only used in build directory testsuite_hooks.h. */
+#define _GLIBCXX_HAVE_LIMIT_DATA 1
+
+/* Only used in build directory testsuite_hooks.h. */
+#define _GLIBCXX_HAVE_LIMIT_FSIZE 1
+
+/* Only used in build directory testsuite_hooks.h. */
+#define _GLIBCXX_HAVE_LIMIT_RSS 1
+
+/* Only used in build directory testsuite_hooks.h. */
+#define _GLIBCXX_HAVE_LIMIT_VMEM 0
+
 /* Define to 1 if you have the <locale.h> header file. */
 #define _GLIBCXX_HAVE_LOCALE_H 1
 
@@ -491,18 +509,6 @@ namespace std
 /* Define to 1 if you have the `mbsrtowcs' function. */
 #define _GLIBCXX_HAVE_MBSRTOWCS 1
 
-/* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCXX_HAVE_MEMLIMIT_AS 1
-
-/* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCXX_HAVE_MEMLIMIT_DATA 1
-
-/* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCXX_HAVE_MEMLIMIT_RSS 1
-
-/* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCXX_HAVE_MEMLIMIT_VMEM 0
-
 /* Define to 1 if you have the <memory.h> header file. */
 #define _GLIBCXX_HAVE_MEMORY_H 1
 
